"""General QuerySets for NDH."""
from django.db.models import QuerySet


class NameOrderedQuerySet(QuerySet):
    """Order a queryset on the "name" field."""
    def name_ordered(self) -> QuerySet:
        """Order by name."""
        return self.order_by('name')



"""General Form-related helpers for NDH."""
from django import forms


class AccessibleDateTimeField(forms.SplitDateTimeField):
    """Set date & time HTML types."""
    widget = forms.SplitDateTimeWidget(date_attrs={'type': 'date'}, time_attrs={'type': 'time'})  # type: ignore



"""General utils for NDH."""
import os
from typing import Optional, TypeVar

from django.db import models
from django.db.models.functions import Coalesce

Numeric = TypeVar('Numeric', int, float)


def full_url(url: str = '', domain: str = None, protocol: str = 'https') -> str:
    """Prepend protocol (default to https) and domain name (default from the Site framework) to an url."""
    if domain is None:
        from django.contrib.sites.models import Site
        domain = Site.objects.get_current().domain
    return f'{protocol}://{domain}{url}'


def query_sum(queryset: models.QuerySet, field: str, output_field: Optional[models.Field] = None) -> Numeric:
    """Let the DBMS perform a sum on a queryset."""
    return queryset.aggregate(s=Coalesce(models.Sum(field), 0, output_field=output_field))['s']


def get_env(env_file: str = '.env') -> None:
    """Set default environment variables from .env file."""
    try:
        with open(env_file) as f_h:
            for line in f_h.readlines():
                try:
                    key, val = line.split('=', maxsplit=1)
                    os.environ.setdefault(key.strip(), val.strip())
                except ValueError:
                    pass
    except FileNotFoundError:
        pass



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['ndh', 'ndh.templatetags']

package_data = \
{'': ['*'],
 'ndh': ['static/css/*',
         'templates/*',
         'templates/ndh/*',
         'templates/registration/*']}

install_requires = \
['django-autoslug>=1.9.8,<2.0.0', 'django-bootstrap5>=2.1.2,<3.0.0']

setup_kwargs = {
    'name': 'ndh',
    'version': '5.0.0',
    'description': "Nim's Django Helpers",
    'long_description': "# Nim's Django Helpers\n\n[![Documentation Status](https://readthedocs.org/projects/ndh/badge/?version=latest)](https://ndh.readthedocs.io/en/latest/?badge=latest)\n[![PyPI version](https://badge.fury.io/py/ndh.svg)](https://pypi.org/project/ndh)\n[![Tests](https://github.com/nim65s/ndh/actions/workflows/test.yml/badge.svg)](https://github.com/nim65s/ndh/actions/workflows/test.yml)\n[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/nim65s/ndh/master.svg)](https://results.pre-commit.ci/latest/github/nim65s/ndh/master)\n[![codecov](https://codecov.io/gh/nim65s/ndh/branch/master/graph/badge.svg?token=BLGISGCYKG)](https://codecov.io/gh/nim65s/ndh)\n[![Maintainability](https://api.codeclimate.com/v1/badges/6737a84239590ddc0d1e/maintainability)](https://codeclimate.com/github/nim65s/ndh/maintainability)\n\n## Requirements\n\n- Python 3.6+\n- Django 3.0+\n- [django-autoslug](https://github.com/justinmayer/django-autoslug)\n- [django-bootstrap5](https://github.com/zostera/django-bootstrap5)\n\n## Install\n\n`pip install ndh`\n",
    'author': 'Guilhem Saurel',
    'author_email': 'guilhem.saurel@laas.fr',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/nim65s/ndh',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
